```
Usage: vcd gateway services ipsec-vpn info [OPTIONS] <gateway name> <local end
                                           point-peer end point>

Options:
  -h, --help  Show this message and exit.

```
